@@ -13,9 +13,8 @@ read.bathy <- function(xyz, header=FALSE, sep=","){
 	if ((bcol*brow) == nrow(bath)) {
 		mat <- matrix(bath[, 3], nrow = brow, ncol = bcol, byrow = FALSE, dimnames = list(lon, lat))
 		} else {
-			id <- apply(bath[,-3],1,function(x) c(which(lon==x[1]) , which(lat==x[2])) )
-			pos.missing <- which(table(id[1,],id[2,])==0)
-			mat <- matrix(add.nas(bath[,3],pos.missing), nrow = brow, ncol = bcol, byrow = FALSE, dimnames = list(lon, lat))
+			colnames(bath) <- paste("V",1:3,sep="")
+			mat <- reshape2::acast(bath, V1~V2, value.var="V3")
 		}
 		
     ordered.mat <- check.bathy(mat)
